<?php

/**
 * @file
 * Administration form for Droptor module.
 */

/**
 * Administration settings for Droptor module.
 */
function droptor_settings_form() {
  module_load_include('inc', 'droptor');
  
  if (variable_get('droptor_debug_mode', 0) == 1) {
    drupal_set_message(t('Droptor debug mode is enabled. This returns additional data to Droptor.com that is helpful with troubleshooting connectivity issues. It is important to disable this mode for production use.'), 'warning');
  }

  $form['droptor_introduction'] = array(
    '#value' => t('!droptor-link is a profiling and best practices service for Drupal. This module feeds information to the Droptor.com web site (mostly about your installed modules and system variables). You can learn more about the module at !support-link.', array(
      '!droptor-link' => l(t('Droptor'), 'http://www.droptor.com/', array('attributes' => array('title' => t('Drupal site organization, monitoring, management and best practices.')))),
      '!support-link' => l(t('our web site'), 'http://www.Droptor.com/support/#droptor-monitoring-module', array('attributes' => array('title' => t('Our support page')))),
    )),
  );

  $form['droptor_hash'] = array(
    '#type' => 'textfield', 
    '#title' => t('Hash key'), 
    '#default_value' => variable_get('droptor_hash', NULL), 
    '#size' => 50, 
    '#maxlength' => 50, 
    '#description' => t("A secret key you get from !droptor-link. For !security-reasons the feed won't be shown unless this key is provided. Register your site at Droptor.com to get this key.", array(
      '!droptor-link' => l(t('Droptor.com'), 'http://www.Droptor.com/sites'),
      '!security-reasons' => l(t('security reasons'), 'http://www.droptor.com/support/#droptor-monitoring-module-security'),
    )), 
    '#required' => TRUE, 
  );
  
  $form['droptor_memory_monitoring'] = array(
    '#type' => 'checkbox', 
    '#title' => t('Enable memory monitoring'), 
    '#default_value' => variable_get('droptor_memory_monitoring', 0), 
    '#description' => droptor_has_memory_management() ? t('When checked Droptor will capture the memory usage and page execution for every page request. <a href="http://www.droptor.com/support#memory-monitoring">More Information</a>.') : t('Your version of PHP does not support this feature. You need at least PHP 5.2.'),
    '#disabled' => droptor_has_memory_management() ? FALSE : TRUE,
    '#required' => FALSE, 
  );
  
  $form['droptor_debug_mode'] = array(
    '#type' => 'checkbox', 
    '#title' => t('Enable debug mode.'), 
    '#default_value' => variable_get('droptor_debug_mode', ''), 
    '#description' => t('Enable debug mode. It is important to disable this mode for production use.'), 
    '#required' => FALSE, 
  );
  
  $form['submit'] = array(
    '#type' => 'submit', 
    '#value' => t('Save'), 
  );

  $form['send-feed'] = array(
    '#type' => 'submit',
    '#value' => t('Send feed to Droptor'),
    '#submit' => array('droptor_settings_send_feed'),
  );

  return $form;  
}

/**
 * Submit callback for admin form. Manually send the feed to Droptor.
 */
function droptor_settings_send_feed() {
  module_load_include('inc', 'droptor', 'droptor');
  if(droptor_send()) {
    drupal_set_message(t('Feed sent to Droptor.'), 'ok');
  }
  else {
    drupal_set_message(t('There was a problem sending the feed to Droptor. Check the error log for more information.'), 'error');
  }
  drupal_goto(DROPTOR_SETTINGS_PAGE_PATH);
}

/**
 * Validation handler for Droptor admin settings form.
 */
function droptor_settings_form_validate(&$form, &$form_state) {
  if (drupal_strlen(trim($form_state['values']['droptor_hash'])) != 40)
    form_set_error('', t('Please enter a hash value. You can get one from Droptor.com.'));
}

/**
 * Submit handler for Droptor admin settings form.
 */
function droptor_settings_form_submit(&$form, &$form_state) {
  variable_set('droptor_hash', $form_state['values']['droptor_hash']);
  variable_set('droptor_memory_monitoring', $form_state['values']['droptor_memory_monitoring']);
  variable_set('droptor_debug_mode', $form_state['values']['droptor_debug_mode']);
  drupal_set_message(t('Settings saved. Your site will send data to Droptor on the next cron run.'));
}
