<?php

/**
 * @file
 * Helper functions for Droptor module.
 */

/**
 * Send the Droptor feed to droptor.com. Called by hook_cron().
 */
function droptor_send() {
	module_load_include('inc', 'droptor', 'droptor.feed');

  // Deliver the Droptor feed to droptor.com.
  $url = variable_get('droptor_feed_deliver_url', 'https://www.droptor.com/inbound');
  $headers = array();
  $method = 'POST';
  $data = array(
    'hash' => variable_get('droptor_hash', NULL),
    'feed' => droptor_feed(),
  );

  // Send the request.
  $ch = curl_init();
  curl_setopt($ch, CURLOPT_URL, $url);
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
  curl_setopt($ch, CURLOPT_POST, true);
  curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
  // Timeout if we can't connect so we don't tie up Cron.
  curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 15);
  // If the feed takes longer than 30 seconds, there is something wrong.
  curl_setopt($ch, CURLOPT_TIMEOUT, 30);
  // If in debug mode it's OK to accept all SSL certs.
  if (variable_get('droptor_debug_mode', 1)) {
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
  }
  $response = curl_exec($ch);
  $response_data = curl_getinfo($ch);
  curl_close($ch);
 
  // Log if debug mode is one
  if(variable_get('droptor_debug_mode', 0) == 1) {
    $message = 'Feed delivery failure. Debugging information: <pre>!response_data</pre>';
    $data = array('!response_data' => print_r($response_data, TRUE));
    watchdog('droptor', $message, $data, WATCHDOG_DEBUG);
  }

  // Log hash or reading data errors.
  switch($response_data['http_code']) {
  	case 401:
  		$message = t('Authorization failure. Did you enter the hash for your site from droptor.com in the Droptor module settings page?');
  		watchdog('droptor', $message, NULL, WATCHDOG_ERROR, url(DROPTOR_SETTINGS_PAGE_PATH, array('absolute' => TRUE)));
  		return FALSE;

  	case 400:
  		$message = t('There is a problem with your feed format. Please contact Droptor support.');
  		watchdog('droptor', $message, NULL, WATCHDOG_ERROR, 'http://www.droptor.com/support');
  		return FALSE;
  }

  // See if Droptor said the feed delivery was successful.
  $response_json = json_decode($response);
  if(!$response_data || empty($response_json->success)) {
  	$message = t('There was a problem sending your feed to droptor. Please contact Droptor support.');
  	watchdog('droptor', $message, NULL, WATCHDOG_INFO, 'http://www.droptor.com/support');
    return FALSE;
  }
  else {
  	$message = t('Feed successfully sent to Droptor.com.');
  	watchdog('droptor', $message, NULL, WATCHDOG_INFO);
    variable_set('droptor_last_successful_sync', time());
    return TRUE;
  }
}

/**
 * Determines if this server support memory management feature
 *
 * @return
 *   True if this site has PHP 5.2 and thus the function we need: memory_get_peak_usage()
 */
function droptor_has_memory_management() {
  return function_exists('memory_get_peak_usage');
}
